@@ -235,7 +235,10 @@ def single_value_select(
         timeout=timeout,
         location=location,
     )
-    return [i for i in result][0].values()[0]
+    if result.total_rows:
+        return [i for i in result][0].values()[0]
+    else:
+        return None
 
 
 def get_time_partition_field(client: bigquery.Client, dataset_id: str, table_id: str):
